# 
# SharPI, V0.1
# 
# SPI (out, 16 bit) for Sharp PC-1403
# (c)ASkr 3/2011
# 
# 
# 11 pin interface:
# 
#    1
#    2
#    3 - GND                   ->   GND
#    4
#    5 - *** &3A00 BIT 2 OUT
#    6
#    7
#    8 - *** &3A00 BIT 3 OUT   ->   CHIP SELECT, active high (for optocoupler)
#    9
#   10 - *** &3A00 BIT 1 OUT   ->   DATA (16 bit)
#   11 - *** &3A00 BIT 0 OUT   ->   CLOCK
# 
# Quiescent state (Sharp turned on) is low.
# After Basic Program is terminated (END), all outputs resturn to low too.
# 
# 

	$JR


VALHI	equ	&0c
VALLO	equ	&0d


	org	&e030

	jp	start	; needs 3 bytes

values:
	db	&00	; h data  (&E033)
	db	&00	; l data  ($E034)

start:
	lidp	values	; copy both arguments to internal RAM
	lip	VALHI
	lii	1	; copy 2 bytes
	mvwd

	lip	VALHI	; future readm with LDM: A <- (P),
	

	lia	1	; 2 bytes
	push

	lidp	&3a00	; port address
	

outer:
	ldm		; read value
	exab		; "copy" to b

	lia	7	; 8 iterations
	push

	lia	&08	; CS high, all other low (not that nice ;-)
	std		; out to port (DP)

inner:	ania	&fe	; clock low
	std

	exab		; data value in a (port in b)
	sl
	jrcp	slow	; set low

shigh:
	exab		; port in a (data value in b)
	oria	&02	; set data pin

	jp	sdone

slow:	exab		; port in a (data value in b)
	ania	&fd	; clear data pin

sdone:	std		; data out
	
	oria	&01	; clock high
	std		; clock and data out

	loop	inner

	incp		; next value

	loop	outer

	lia	0	; all outputs low
	std		; out to port

	rtn
